<div class="mainBox">
  <h2><a name="xml" id="xml">Custom Tags with XMLSubsMatch</a></h2>
Before XML, there was the need to make HTML markup smarter. Ruby/ASP gives you the ability to have a Ruby subroutine handle the execution of any predefined tag, taking the tag descriptors, and the text contained between, as block of the subroutine. This custom tag technology can be used to extend a web developer's abilities to add dynamic pieces without having to visibly use &lt;% %&gt; style code entries.

<p></p>
So, lets say that you have a table that you want to insert for an employee with contact info and the like, you could set up a tag like:

<pre>
&lt;my:new-employee name="Jane" last="Doe" phone="555-2222"&gt;
  Jane Doe has been here since 1998.
&lt;/my:new-employee&gt;
</pre>

Any colons, ':', in the XML custom tag will turn into '::', a Ruby module separator, so the my:employee tag would translate to the my::employee subroutine, or the employee subroutine in the my module. Any dash "-" will also be translated to an underscore "_", as dash is not valid in the names of Ruby subroutines.

<p></p>
Then you would create the my::employee subroutine in the my ruby module or whereever like so:

<pre>
module My
  def My::test( h )
    print "&lt;B&gt;In My::Test&lt;/B&gt;&lt;BR&gt;\n"
    yield if block_given?
    h.each_pair { |k,v|
      print "#{k} =&gt; #{v}&lt;BR&gt;\n"
    }
  end
end
</pre>

Though XML purists would not like this custom tag technology to be related to XML, the reality is that a careful site engineer could render full XML documents with this technology, applying all the correct styles that one might otherwise do with XSLT.

<p></p>
Custom tags defined in this way can be used as XML tags are defined with both a body and without as it

<pre>
&lt;my:new-employee&gt;...&lt;/my:new-employee&gt;
</pre>

and just

<pre>
&lt;my:new-employee /&gt;
</pre>

These tags are very powerful in that they can also enclose normal ASP logic, like:

<pre>
&lt;my:new-employee&gt;
  &lt;!-- normal ASP logic --&gt;
  &lt;% birthday = Time::new %&gt;

  &lt;!-- ASP inserts --&gt;
  This employee has been online for &lt;%= Integer(rand()*600)+1 %&gt;
  seconds, and was born near &lt;%= birthday %&gt;.
&lt;/my:new-employee&gt;   
</pre>

For an example of this custom XML tagging in action, please check out the tests/subsmatch.asp script.
</div>

<div class="interBox">[<a href="#idx-top">top</a>]</div>
